@@ -94,6 +94,7 @@ def _setupVars():
     #PBS {o_dependencies}
     #PBS {o_options}
     #PBS {o_env}
+    #PBS {o_block}
     {env}
     {header_commands}
     ARRAY_IND=$PBS_ARRAYID
@@ -116,6 +117,7 @@ def _setupVars():
     #$ {o_dependencies}
     #$ {o_options}
     #$ {o_env}
+    #$ {o_block}
     {env}
     {header_commands}
     ARRAY_IND=$SGE_TASK_ID
@@ -137,6 +139,7 @@ def _setupVars():
     #SBATCH {o_dependencies}
     #SBATCH {o_options}
     #SBATCH {o_env}
+    #SBATCH {o_block}
     {env}
     {header_commands}
     ARRAY_IND=$SLURM_ARRAY_TASK_ID
@@ -369,6 +372,7 @@ def qbatchDriver(**kwargs):
     system = kwargs.get('system')
     env_mode = kwargs.get('env')
     shell = kwargs.get('shell')
+    block = kwargs.get('block')
 
     mkdirp(logdir)
 
@@ -397,6 +401,7 @@ def qbatchDriver(**kwargs):
                     sys.exit("qbatch: error: command_file {0}".format(file) +
                              " does not exist or cannot be read")
     else:
+        task_list = kwargs.get('task_list')
         job_name = job_name or 'qbatchDriver'
 
     # compute the number of jobs needed. This will be the number of elements in
@@ -459,6 +464,7 @@ def qbatchDriver(**kwargs):
         o_memopts = (mem and mem_string) and '-l {0}'.format(mem_string) or ''
         o_env = (env_mode == 'batch') and '-V' or ''
         o_queue = queue and '-q {0}'.format(queue) or ''
+        o_block = block and " -Wblock=true" or ''
 
         header = PBS_HEADER_TEMPLATE.format(**vars())
 
@@ -473,6 +479,7 @@ def qbatchDriver(**kwargs):
         o_memopts = (mem and mem_string) and '-l {0}'.format(mem_string) or ''
         o_env = (env_mode == 'batch') and '-V' or ''
         o_queue = queue and '-q {0}'.format(queue) or ''
+        o_block = block and " -sync y" or ''
 
         header = SGE_HEADER_TEMPLATE.format(**vars())
 
@@ -502,6 +509,7 @@ def qbatchDriver(**kwargs):
             logdir, job_name) or '--output={0}/slurm-{1}-%j.out'.format(
             logdir, job_name)
         o_queue = queue and '--partition={0}'.format(queue) or ''
+        o_block = block and " --wait" or ''
 
         header = SLURM_HEADER_TEMPLATE.format(**vars())
 
@@ -749,6 +757,10 @@ def qbatchParser(args=None):
         "--shell", default=SHELL,
         help="""Shell to use for spawning jobs
         and launching single commands""")
+    group.add_argument(
+        "--block", action="store_true",
+        help="""For SGE, PBS and SLURM, blocks execution until jobs are
+        finished.""")
 
     args = parser.parse_args(args)
     if not args.command_file:
